==> zither-1.1.13.tar.gz: zither_prj/zither/neg.c <==
// neg.c
// $Id: neg.c,v 1.1.1.1 2007/09/19 05:49:54 sendan Exp $
// masashi shimakura

#include<stdio.h>
#include<unistd.h>
#include<sys/socket.h>
#include<netinet/in_systm.h>
#include<netinet/in.h>
#include<netinet/ip.h>
#include<arpa/inet.h>
#include<stdlib.h>
#include<string.h>
#include<pthread.h>

#include"zither.h"
#include<almemsys/almemsys.h>



/*
int lockfile_remove(void);
int neg(char *);
int chack_lockfile(char *);
int lock_remove(char *);
*/



int lockfile_remove(char * neg_filename, char * lock_path, char * conf_path)
{
static int ret;
FILE * fp;
int fp_stat = 0;
int count0 = 0;
int count1 = 0;
char chA;
char data[2][BUF_LEN];
char * alllock_filename = (char *)calloc(BUF_DEFLEN, sizeof(char));

ret = 0;
if((fp = fopen(neg_filename, "r+"))!=NULL){
   while(fp_stat == 0){
      chA = fgetc(fp);
      switch(chA){
         case ':' : data[count0][count1] = (char)0x00;
                    if(count0 < 2){
                       count0++; count1 = 0;
                       }
                    break;
         case ';' : data[count0][count1] = (char)0x00;
                    if(count1 != 0){
                       if(0 != strlen(data[count0])){
                          alllock_filename = filename_create(alllock_filename, lock_path, "_lock", data[0]);
                          lock_remove(alllock_filename);
                          alllock_filename = filename_create(alllock_filename, conf_path, ".list_lock", data[0]);
                          lock_remove(alllock_filename);
                          alllock_filename = filename_create(alllock_filename, conf_path, ".stat_lock", data[0]);
                          lock_remove(alllock_filename);
                          alllock_filename = filename_create(alllock_filename, conf_path, ".conf_lock", data[0]);
                          lock_remove(alllock_filename);
                          alllock_filename = filename_create(alllock_filename, conf_path, ".command_lock", data[0]);
                          lock_remove(alllock_filename);
                          }
                       count0 = 0; count1 = 0;
                       }
                    break;
         case '\n' : data[count0][count1] = (char)0x00;
                    if(count1 != 0){
                       if(0 != strlen(data[count0])){
                          alllock_filename = filename_create(alllock_filename, lock_path, "_lock", data[0]);
                          lock_remove(alllock_filename);
                          alllock_filename = filename_create(alllock_filename, conf_path, ".list_lock", data[0]);
                          lock_remove(alllock_filename);
                          alllock_filename = filename_create(alllock_filename, conf_path, ".stat_lock", data[0]);
                          lock_remove(alllock_filename);
                          alllock_filename = filename_create(alllock_filename, conf_path, ".conf_lock", data[0]);
                          lock_remove(alllock_filename);
                          alllock_filename = filename_create(alllock_filename, conf_path, ".command_lock", data[0]);
                          lock_remove(alllock_filename);
                          }
                       count0 = 0; count1 = 0;
                       }
                    break;
         case EOF : fp_stat = 1;
                    data[count0][count1] = (char)0x00;
                    break;
         default  : data[count0][count1] = chA;
                    if(count1 < IP_LEN){
                       count1++;
                       }
                    break;
         }
      }
   fclose(fp);
   free(alllock_filename);
   }
else {
   fprintf(stderr,"There is no nego list file. %s\n", neg_filename);
   ret = 0;
   }

return(ret);
} 




int neg(char * user, char * neg_filename, unsigned char * chIpadd)
{
static int ret;
FILE * fp;
int fp_stat = 0;
int count0 = 0;
int count1 = 0;
char chA;
char data[2][BUF_LEN];
char ia[IP_LEN];
char * ipad = ia;

sprintf(ipad,"%d.%d.%d.%d", chIpadd[0],chIpadd[1],chIpadd[2],chIpadd[3]);

ret = 0;
if((fp = fopen(neg_filename, "r+"))!=NULL){
   while(fp_stat == 0){
      chA = fgetc(fp);
      switch(chA){
         case ':' : data[count0][count1] = (char)0x00;
                    if(count0 < 2){
                       count0++; count1 = 0;
                       }
                    break;
         case ';' : data[count0][count1] = (char)0x00;
                    if(count1 != 0){
                       if(0 == strcmp(data[0], user) && 0 == strcmp(data[1], ipad)){
                          ret = 1;
                          }
                       count0 = 0; count1 = 0;
                       }
                    break;
         case '\n' : data[count0][count1] = (char)0x00;
                    if(count1 != 0){
                       if(0 == strcmp(data[0], user) && 0 == strcmp(data[1], ipad)){
                          ret = 1;
                          }
                       count0 = 0; count1 = 0;
                       }
                    break;
         case EOF : fp_stat = 1;
                    data[count0][count1] = (char)0x00;
                    break;
         default  : data[count0][count1] = chA;
                    if(count1 < IP_LEN){
                       count1++;
                       }
                    break; 
         }
      }
   fclose(fp);
   }
else {
   fprintf(stderr,"There is no nego list file. %s\n", neg_filename);
   ret = 0;
   } 

return(ret);
}



int lock_remove(char * lock_filename)
{
static int stat;

stat = remove(lock_filename);

if(stat == 0){
   fprintf(stderr,"The LOCK file was normally deleted. name=%s\n", lock_filename);
   }
else {
   fprintf(stderr,"The LOCK file cannot be deleted. stat=%d name=%s\n", stat, lock_filename);
   }
return(stat);
}



char * chack_lockfile(char * user, char * info, char * lock_filename, char * lock_path, int * stat)
{
FILE * fp;

*stat = 0;

lock_filename = filename_create(lock_filename, lock_path, "_lock", user);

if((fp = fopen(lock_filename, "r"))==NULL){
   if((fp = fopen(lock_filename, "w+"))!=NULL){
      fprintf(fp,"user = %s:info = %s:pid = %d\n", user, info, (int)getpid());
      fclose(fp);
      *stat = 1;
      }
   else{
      fprintf(stderr,"The Lock file cannot be made. %s\n", lock_filename);
      *stat = 0;
      }
   }
else{
   fprintf(stderr,"The Lock file exists. %s\n", lock_filename);
   fclose(fp);
   *stat = 0;
   }
return lock_filename;
}

==> zither-1.1.16.tar.gz: zither_prj/zither/neg.c <==
#include<stdio.h>
#include<unistd.h>
#include<sys/socket.h>
#include<netinet/in_systm.h>
#include<netinet/in.h>
#include<netinet/ip.h>
#include<arpa/inet.h>
#include<stdlib.h>
#include<string.h>
#include<pthread.h>

#include"zither.h"
#include<almemsys/almemsys.h>


/*
int neg(char *);
*/


int neg(char * user, char * neg_filename, unsigned char * chIpadd)
{
static int ret;
FILE * fp;
int fp_stat = 0;
int count0 = 0;
int count1 = 0;
char chA;
char data[2][BUF_LEN];
char ia[IP_LEN];
char * ipad = ia;

sprintf(ipad,"%d.%d.%d.%d", chIpadd[0],chIpadd[1],chIpadd[2],chIpadd[3]);

ret = 0;
if((fp = fopen(neg_filename, "r+"))!=NULL){
   while(fp_stat == 0){
      chA = fgetc(fp);
      switch(chA){
         case ':' : data[count0][count1] = (char)0x00;
                    if(count0 < 2){
                       count0++; count1 = 0;
                       }
                    break;
         case ';' : data[count0][count1] = (char)0x00;
                    if(count1 != 0){
                       if(0 == strcmp(data[0], user) && 0 == strcmp(data[1], ipad)){
                          ret = 1;
                          }
                       count0 = 0; count1 = 0;
                       }
                    break;
         case '\n' : data[count0][count1] = (char)0x00;
                    if(count1 != 0){
                       if(0 == strcmp(data[0], user) && 0 == strcmp(data[1], ipad)){
                          ret = 1;
                          }
                       count0 = 0; count1 = 0;
                       }
                    break;
         case EOF : fp_stat = 1;
                    data[count0][count1] = (char)0x00;
                    break;
         default  : data[count0][count1] = chA;
                    if(count1 < IP_LEN){
                       count1++;
                       }
                    break; 
         }
      }
   fclose(fp);
   }
else {
   fprintf(stderr,"neg(): There is no nego list file. %s\n", neg_filename);
   ret = 0;
   } 

return(ret);
}
